#[non_exhaustive]pub enum BundleLayoutInvalidReason {
AgentEqualsOwner,
AgentNestedInOwner,
OwnerNestedInAgent,
EmptyPath,
}Expand description
Closed reason set for invalid SafeBundle agent/owner output layouts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AgentEqualsOwner
Agent and owner outputs resolve to the same directory.
AgentNestedInOwner
The agent output directory is nested inside the owner output directory.
OwnerNestedInAgent
The owner output directory is nested inside the agent output directory.
EmptyPath
One output path was empty and cannot name a directory.