#[non_exhaustive]pub enum PdfPagePayload {
VectorText {
text: String,
page_index: i32,
page_count: i32,
},
Raster(RasterizedPage),
}Available on crate feature
pdf-input only.Expand description
Per-page PDF extraction payload.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
VectorText
Page had selectable text and did not require OCR.
Fields
Raster(RasterizedPage)
Page had no selectable text and was rasterized for OCR.
Implementations
Sourceimpl PdfPagePayload
impl PdfPagePayload
Sourcepub fn page_index(&self) -> i32
pub fn page_index(&self) -> i32
Zero-based page index.
Sourcepub fn page_count(&self) -> i32
pub fn page_count(&self) -> i32
Total page count in the source document.